pub enum AstError {
NodeNotFound,
NodeNotModifiable,
InvalidOperation,
LanguageSpecific(String),
}Expand description
Error type for AST operations.
Variants
NodeNotFound
The operation failed because the node was not found.
NodeNotModifiable
The operation failed because the node is not modifiable.
InvalidOperation
The operation failed because of an invalid operation.
LanguageSpecific(String)
The operation failed because of a language-specific error.