Module errors

Module errors 

Error handling and diagnostic reporting for the parsing system.

Structs

OakDiagnostics
Diagnostic information for parsing operations.
OakError
The main error type for the Oak Core parsing framework.

Enums

OakErrorKind
Enumeration of all possible error kinds in the Oak Core framework.

Type Aliases

ParseResult
Result type for parsing operations.