pub struct ContentCache<L: Language + Send + Sync + 'static> { /* private fields */ }Expand description
A content-based cache for parsed results.
This cache stores parsed results based on the hash of the source content, allowing for efficient reuse of parsing results when processing the same content multiple times.
Implementations
Sourceimpl<L: Language + Send + Sync + 'static> ContentCache<L>
impl<L: Language + Send + Sync + 'static> ContentCache<L>
Sourcepub fn new(max_entries: usize) -> Self
pub fn new(max_entries: usize) -> Self
Creates a new content cache with the specified maximum size.
Sourcepub fn get<S: Source + ?Sized>(
&self,
source: &S,
) -> Option<(&GreenNode<'_, L>, &LexOutput<L>)>
pub fn get<S: Source + ?Sized>( &self, source: &S, ) -> Option<(&GreenNode<'_, L>, &LexOutput<L>)>
Gets a cached entry for the given source content if it exists.